==> tekton-model-triggers-v1alpha1-6.3.0-sources.jar: io/fabric8/tekton/triggers/v1alpha1/CELInterceptorFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface CELInterceptorFluent<A extends CELInterceptorFluent<A>> extends Fluent<A>{
  public String getFilter();
  public A withFilter(String filter);
  public Boolean hasFilter();
  public A addToOverlays(Integer index,CELOverlay item);
  public A setToOverlays(Integer index,CELOverlay item);
  public A addToOverlays(io.fabric8.tekton.triggers.v1alpha1.CELOverlay... items);
  public A addAllToOverlays(Collection<CELOverlay> items);
  public A removeFromOverlays(io.fabric8.tekton.triggers.v1alpha1.CELOverlay... items);
  public A removeAllFromOverlays(Collection<CELOverlay> items);
  public A removeMatchingFromOverlays(Predicate<CELOverlayBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildOverlays instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<CELOverlay> getOverlays();
  public List<CELOverlay> buildOverlays();
  public CELOverlay buildOverlay(Integer index);
  public CELOverlay buildFirstOverlay();
  public CELOverlay buildLastOverlay();
  public CELOverlay buildMatchingOverlay(Predicate<CELOverlayBuilder> predicate);
  public Boolean hasMatchingOverlay(Predicate<CELOverlayBuilder> predicate);
  public A withOverlays(List<CELOverlay> overlays);
  public A withOverlays(io.fabric8.tekton.triggers.v1alpha1.CELOverlay... overlays);
  public Boolean hasOverlays();
  public A addNewOverlay(String expression,String key);
  public CELInterceptorFluent.OverlaysNested<A> addNewOverlay();
  public CELInterceptorFluent.OverlaysNested<A> addNewOverlayLike(CELOverlay item);
  public CELInterceptorFluent.OverlaysNested<A> setNewOverlayLike(Integer index,CELOverlay item);
  public CELInterceptorFluent.OverlaysNested<A> editOverlay(Integer index);
  public CELInterceptorFluent.OverlaysNested<A> editFirstOverlay();
  public CELInterceptorFluent.OverlaysNested<A> editLastOverlay();
  public CELInterceptorFluent.OverlaysNested<A> editMatchingOverlay(Predicate<CELOverlayBuilder> predicate);
  public interface OverlaysNested<N> extends Nested<N>,CELOverlayFluent<CELInterceptorFluent.OverlaysNested<N>>{
    public N and();
    public N endOverlay();
    
  }
  
}

==> tekton-model-triggers-v1alpha1-6.7.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/CELInterceptorFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface CELInterceptorFluent<A extends CELInterceptorFluent<A>> extends Fluent<A>{
  public String getFilter();
  public A withFilter(String filter);
  public Boolean hasFilter();
  public A addToOverlays(int index,CELOverlay item);
  public A setToOverlays(int index,CELOverlay item);
  public A addToOverlays(io.fabric8.tekton.triggers.v1alpha1.CELOverlay... items);
  public A addAllToOverlays(Collection<CELOverlay> items);
  public A removeFromOverlays(io.fabric8.tekton.triggers.v1alpha1.CELOverlay... items);
  public A removeAllFromOverlays(Collection<CELOverlay> items);
  public A removeMatchingFromOverlays(Predicate<CELOverlayBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildOverlays instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<CELOverlay> getOverlays();
  public List<CELOverlay> buildOverlays();
  public CELOverlay buildOverlay(int index);
  public CELOverlay buildFirstOverlay();
  public CELOverlay buildLastOverlay();
  public CELOverlay buildMatchingOverlay(Predicate<CELOverlayBuilder> predicate);
  public Boolean hasMatchingOverlay(Predicate<CELOverlayBuilder> predicate);
  public A withOverlays(List<CELOverlay> overlays);
  public A withOverlays(io.fabric8.tekton.triggers.v1alpha1.CELOverlay... overlays);
  public Boolean hasOverlays();
  public A addNewOverlay(String expression,String key);
  public CELInterceptorFluent.OverlaysNested<A> addNewOverlay();
  public CELInterceptorFluent.OverlaysNested<A> addNewOverlayLike(CELOverlay item);
  public CELInterceptorFluent.OverlaysNested<A> setNewOverlayLike(int index,CELOverlay item);
  public CELInterceptorFluent.OverlaysNested<A> editOverlay(int index);
  public CELInterceptorFluent.OverlaysNested<A> editFirstOverlay();
  public CELInterceptorFluent.OverlaysNested<A> editLastOverlay();
  public CELInterceptorFluent.OverlaysNested<A> editMatchingOverlay(Predicate<CELOverlayBuilder> predicate);
  public interface OverlaysNested<N> extends Nested<N>,CELOverlayFluent<CELInterceptorFluent.OverlaysNested<N>>{
    public N and();
    public N endOverlay();
    
  }
  
}
